@@ -154,27 +154,27 @@ class Zettel:
 
         event.add('dtstamp', parse_date('today'))
 
-        if 'event_begin' in self and self.event_begin:
-            event.add('dtstart', self.event_begin.date)
-        elif 'due_date' in self and self.due_date:
-            event.add('dtstart', self.due_date.date)
+        if 'event_begin' in self.attrs and self.attrs['event_begin']:
+            event.add('dtstart', self.attrs['event_begin']._date)
+        elif 'due_date' in self.attrs and self.attrs['due_date']:
+            event.add('dtstart', self.attrs['due_date']._date)
 
         # recurring zettels should also have event_begin
-        if 'recurring' in self and self.recurring:
-            rrule = self.recurring
+        if 'recurring' in self and self.attrs['recurring']:
+            rrule = self.attrs['recurring']
 
-            if 'recurring_stop' in self and self.recurring_stop:
-                rrule += f';until={self.recurring_stop.asRrule()}'
+            if 'recurring_stop' in self.attrs and self.attrs['recurring_stop']:
+                rrule += f';until={self.attrs["recurring_stop"].asRrule()}'
 
             event['rrule'] = parse_rrule(rrule)
 
         # Add duration.
-        if 'duration' in self and self.duration:
-            event.add('duration', parse_duration(self.duration))
+        if 'duration' in self.attrs and self.attrs['duration']:
+            event.add('duration', parse_duration(self.attrs['duration']))
 
         # Parse dtend
-        if 'event_end' in self and self.event_end:
-            event.add('dtend', self.event_end.date)
+        if 'event_end' in self.attrs and self.attrs['event_end']:
+            event.add('dtend', self.attrs['event_end']._date)
 
         return event
 
